==> buildpack-client-0.0.6-sources.jar: dev/snowdrop/buildpack/docker/StringContentFluentImpl.java <==
package dev.snowdrop.buildpack.docker;

import dev.snowdrop.buildpack.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StringContentFluentImpl<A extends dev.snowdrop.buildpack.docker.StringContentFluent<A>> extends dev.snowdrop.buildpack.builder.BaseFluent<A> implements dev.snowdrop.buildpack.docker.StringContentFluent<A>{
  public StringContentFluentImpl() {
  }
  public StringContentFluentImpl(dev.snowdrop.buildpack.docker.StringContent instance) {
    this.withPath(instance.getPath()); 
    this.withContent(instance.getContent()); 
  }
  private java.lang.String path;
  private java.lang.String content;
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  public java.lang.String getContent() {
    return this.content;
  }
  public A withContent(java.lang.String content) {
    this.content=content; return (A) this;
  }
  public java.lang.Boolean hasContent() {
    return this.content != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StringContentFluentImpl that = (StringContentFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (content != null ? !content.equals(that.content) :that.content != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  content,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.14-sources.jar: dev/snowdrop/buildpack/docker/StringContentFluentImpl.java <==
package dev.snowdrop.buildpack.docker;

import java.lang.Integer;
import dev.snowdrop.buildpack.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StringContentFluentImpl<A extends dev.snowdrop.buildpack.docker.StringContentFluent<A>> extends dev.snowdrop.buildpack.builder.BaseFluent<A> implements dev.snowdrop.buildpack.docker.StringContentFluent<A>{
  public StringContentFluentImpl() {
  }
  public StringContentFluentImpl(dev.snowdrop.buildpack.docker.StringContent instance) {
    this.withPath(instance.getPath()); 
    this.withContent(instance.getContent()); 
  }
  private java.lang.String path;
  private java.lang.Integer mode;
  private java.lang.String content;
  public java.lang.String getPath() {
    return this.path;
  }
  public A withPath(java.lang.String path) {
    this.path=path; return (A) this;
  }
  public java.lang.Boolean hasPath() {
    return this.path != null;
  }
  public java.lang.Integer getMode() {
    return this.mode;
  }
  public A withMode(java.lang.Integer mode) {
    this.mode=mode; return (A) this;
  }
  public java.lang.Boolean hasMode() {
    return this.mode != null;
  }
  public java.lang.String getContent() {
    return this.content;
  }
  public A withContent(java.lang.String content) {
    this.content=content; return (A) this;
  }
  public java.lang.Boolean hasContent() {
    return this.content != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StringContentFluentImpl that = (StringContentFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    if (content != null ? !content.equals(that.content) :that.content != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  mode,  content,  super.hashCode());
  }
  
}
